# NARpyn
> A Python API library for NARS

[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
![Black Badge](https://img.shields.io/badge/code%20style-black-000000.svg)
![RuffGit Badge](https://github.com/ntoxeg/narpyn/workflows/RuffGit/badge.svg)

Currently supported backends include OpenNARS for Applications (ONA).
